@@ -5,7 +5,7 @@
 #' per row, iteratively evaluate the model over the set of 
 #' new values.
 #' 
-#' New parameters with a missing value (\code{NA}) do not
+#' New parameters with a missing value (\code{NA}) do not 
 #' replace existing parameters.
 #' 
 #' @param model An \code{uneval_model} object.
@@ -14,6 +14,8 @@
 #' @param init numeric vector, same length as number of 
 #'   model states. Number of individuals in each model state
 #'   at the beginning.
+#' @param old_parameters Current parameters used to compute
+#'   model.
 #' @param newdata a data.frame whose names match parameters 
 #'   names. \code{model} will be evaluated iteratively, 
 #'   taking successivel values from each row.
@@ -22,55 +24,28 @@
 #' @return A data.frame containing the values of 
 #'   \code{newdata} and each Markov Model evaluation in 
 #'   \code{res}.
-#'   
-#'   
-#' @examples
 #' 
-#' \dontrun{
-#' par1 <- define_parameters(
-#'   a = 1,
-#'   b = 1 / (markov_cycle + a)
-#' )
+#' @example inst/examples/example_eval_model_newdata.R
 #' 
-#' mat1 <- define_matrix(
-#'   1-b, b,
-#'   0, 1
-#' )
+eval_model_newdata <- function(model,
+                               old_parameters,
+                               newdata,
+                               cycles,
+                               init, method) {
 
-#' mod1 <- define_model(
-#'   parameters = par1,
-#'   transition_matrix = mat1,
-#'   define_state(var = a),
-#'   define_state(var = a * markov_cycle)
-#' )
-#' 
-#' new_tab <- data.frame(
-#'   a = 1:10
-#' )
-#' 
-#' eval_model_newdata(
-#'   mod1,
-#'   cycles = 5,
-#'   init = 1:0,
-#'   newdata = new_tab
-#' )
-#' }
-#' 
-eval_model_newdata <- function(model, cycles,
-                               init, method,
-                               newdata) {
-  
-  eval_newdata <- function(new_params, model) {
-    new_params <- Filter(function(x) !is.na(x), new_params)
+  eval_newdata <- function(new_parameters, model, old_parameters) {
+    new_parameters <- Filter(function(x) !is.na(x), new_parameters)
     
-    lazy_new_param <- do.call(lazyeval::lazy_dots, new_params)
+    lazy_new_param <- do.call(lazyeval::lazy_dots, new_parameters)
     
-    model$parameters <- modifyList(
-      get_parameters(model),
+    parameters <- modifyList(
+      old_parameters,
       lazy_new_param
     )
+    
     eval_model(
       model = model,
+      parameters = parameters,
       cycles = cycles,
       init = init,
       method = method
@@ -81,7 +56,8 @@ eval_model_newdata <- function(model, cycles,
     newdata,
     dplyr::do(
       dplyr::rowwise(newdata),
-      get_total_state_values(eval_newdata(., model))
+      get_total_state_values(eval_newdata(., model = model,
+                                          old_parameters = old_parameters))
     )
   )
 }
@@ -120,7 +96,8 @@ run_newdata <- function(x, newdata) {
   ce <- attr(x, "ce")
   
   list_res <- lapply(list_models, eval_model_newdata, method = method,
-                     init = init, cycles = cycles, newdata = newdata)
+                     old_parameters = get_parameters(x), newdata = newdata,
+                     init = init, cycles = cycles)
   
   for (n in names(list_res)) {
     list_res[[n]]$.model_names <- n
